@@ -66,7 +66,7 @@ import com.openexchange.usm.api.exceptions.DeserializationFailedException;
  * @author afe
  *
  */
-public interface DataObject {
+public interface DataObject extends Serializable {
 	/**
 	 * @return Session with which this DataObject is associated
 	 */
