@@ -128,7 +128,7 @@ public class USMSessionTool {
             "usmsessions [USM-Request-URL-parameters or USM-Session-filter]+",
             "",
             toolOptions,
-            "Options -d,-e,-r are mutually exclusive, as are options -q,-v.\nArguments may be given as EAS-POST-URL-parameters, OLOX2-PUT-URL-parameters, or an USM-session-filter.\nAn USM-session-filter consists of 5 parts, separated by colon(\":\"):\nContext-ID:OX-User-ID:USM-Session-ID:USM-Protocol:Device-ID\nEach part may be left empty to match any value.\nCurrently available USM-protocols are: EAS, JSON.");
+            "Options -d,-e,-r are mutually exclusive, as are options -q,-v.\nArguments may be given as EAS-POST-URL-parameters, OLOX2-PUT-URL-parameters, or an USM-session-filter.\nAn USM-session-filter consists of 5 parts, separated by colon(\":\"):\nContext-ID:OX-User-ID:USM-Session-ID:USM-Protocol:Device-ID\nEach part may be left empty to match any value.\nCurrently available USM-protocols are: EAS, JSON.\nExamples (from webserver-log):\nEAS: /Microsoft-Server-ActiveSync?Cmd=Sync&User=user&DeviceId=SomeDeviceId&DeviceType=Android\nOLOX2:\n/usm-json/syncUpdate?id=SomeId");
         System.exit(0);
     }
 
