@@ -72,20 +72,20 @@ public class ConfigurationProperties {
     public static final String USM_SESSION_STORAGE_TIME_LIMIT_PROPERTY = "com.openexchange.usm.session_storage_time_limit";
 
     public static final int USM_SESSION_STORAGE_TIME_LIMIT_DEFAULT = 60; // 60 days
-    
+
     /**
      * 
      */
     public static final String USM_SESSION_CACHE_CHECK_INTERVAL_PROPERTY = "com.openexchange.usm.session_cache_check_interval";
-    
-    public static final int USM_SESSION_CACHE_CHECK_INTERVAL_DEFAULT = 60000; //1 minute
-    
+
+    public static final int USM_SESSION_CACHE_CHECK_INTERVAL_DEFAULT = 60000; // 1 minute
+
     /**
      * 
      */
     public static final String USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_PROPERTY = "com.openexchange.usm.session_cache_check_interval_log_info";
-    
-    public static final int USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_DEFAULT = 300000; //5 minutes
+
+    public static final int USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_DEFAULT = 300000; // 5 minutes
 
     /**
      * Specifies a timeout (in seconds) after which USM sessions that are not accessed will be removed from memory. Removed sessions will be
@@ -326,6 +326,10 @@ public class ConfigurationProperties {
 
     public static final boolean JSON_SERVLET_FATAL_UUID_ERRORS_DEFAULT = false;
 
+    public static final String JSON_SERVLET_MAX_EMAIL_SIZE_PROPERTY = "com.openexchange.usm.json.max_email_size";
+
+    public static final int JSON_SERVLET_MAX_EMAIL_SIZE_DEFAULT = 50 * 1024 * 1024; // 50 MByte
+
     /**
      * Defines the lower time filter limit in days. Appointments and mails which are in the past beyond this limit will not be synchronised
      * from/to the client.
@@ -399,4 +403,8 @@ public class ConfigurationProperties {
     public static final String USM_FORCE_NEW_SYNC_KEY_ON_EMPTY_SYNC = "com.openexchange.usm.force_new_sync_key_on_empty_sync";
 
     public static final boolean USM_FORCE_NEW_SYNC_KEY_ON_EMPTY_SYNC_DEFAULT = false;
+
+    public static final String OBJECTS_IN_FOLDER_SYNC_LIMIT_PROPERTY = "com.openexchange.usm.max_objects_per_folder";
+
+    public static final int OBJECTS_IN_FOLDER_SYNC_LIMIT_DEFAULT = 65535;
 }
