@@ -130,12 +130,15 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 		Session session = folder.getSession();
 		parameters.put(UtilConstants.START, String.valueOf(session.getStartDate()));
 		parameters.put(UtilConstants.END, String.valueOf(session.getEndDate()));
-
+		if(folder.getSession().getObjectsLimit() > 0) {
+		    addObjectsLimitParameters(folder.getSession().getObjectsLimit(), parameters);
+		}
 		DataObject[] result = performActionAndCheckRights(UtilConstants.ACTION_ALL, folder, requestedFields, parameters);
 
 		resetRecurrenceTypeBasedFields(result);
 		return result;
 	}
+	
 
 	public DataObject[] getAllAppointments(Session session, BitSet requestedFields) throws USMException {
 		if (_journal.isDebugEnabled())
@@ -147,6 +150,10 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 		parameters.put(UtilConstants.START, String.valueOf(session.getStartDate()));
 		parameters.put(UtilConstants.END, String.valueOf(session.getEndDate()));
 		parameters.put(UtilConstants.RECURRENCE_MASTER, Boolean.TRUE.toString());
+		
+		if(session.getObjectsLimit() > 0) {
+            addObjectsLimitParameters(session.getObjectsLimit(), parameters);
+        }
 
 		JSONResult jsonResult = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, session, parameters);
 		DataObject[] result = buildResultArray(session, requestedFields, jsonResult);
@@ -172,6 +179,10 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 		if (folder != null)
 			parameters.put(UtilConstants.FOLDER, folder);
 		parameters.put(UtilConstants.RECURRENCE_MASTER, Boolean.FALSE.toString());
+		
+		if(session.getObjectsLimit() > 0) {
+            addObjectsLimitParameters(session.getObjectsLimit(), parameters);
+        }
 
 		JSONResult jsonResult = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, session, parameters);
 		JSONArray jArray = extractArrayResult(jsonResult);
@@ -524,9 +535,8 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 	public DataObject[] readUpdatedFolderContent(Folder folder, BitSet requestedFields, long timestamp)
 			throws USMException {
 		Session session = folder.getSession();
-		// XXX Why do we use ACTION_ALL here ? Shouldn't we do only an update ?
 		DataObject[] result = readStandardUpdatedFolderContent(folder, timestamp, requestedFields,
-				UtilConstants.ACTION_ALL, UtilConstants.FOLDER, null, null, String.valueOf(session.getStartDate()),
+				UtilConstants.ACTION_UPDATES, UtilConstants.FOLDER, null, null, String.valueOf(session.getStartDate()),
 				String.valueOf(session.getEndDate()));
 		resetRecurrenceTypeBasedFields(result);
 		return result;
