@@ -71,6 +71,7 @@ import com.openexchange.usm.api.contenttypes.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.PictureConversionException;
 import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
+import com.openexchange.usm.api.exceptions.ConflictingChangeException;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMException;
@@ -234,22 +235,16 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 					+ ", no appropriate ImageReader found.");
 			return null;
 		}
-		int type = sourceImage.getType();
-		if (type == 0)
-			type = BufferedImage.TYPE_INT_RGB;
-		for (int i = 0; i < 6; i++) {
-			int scaledWidth = Math.round(sourceImage.getWidth() * scaleFactor);
-			int scaledHeight = Math.round(sourceImage.getHeight() * scaleFactor);
-			BufferedImage scaledImage = sourceImage;
-			if (scaleFactor < 1.0f) {
-				scaledImage = new BufferedImage(scaledWidth, scaledHeight, BufferedImage.TYPE_INT_RGB);
-				Graphics2D g = scaledImage.createGraphics();
-                g.setColor(Color.WHITE);
-                g.fillRect(0, 0, scaledWidth, scaledHeight);
-				g.drawImage(sourceImage, 0, 0, scaledWidth, scaledHeight, null);
-				g.dispose();
-			}
-			ByteArrayOutputStream os = new ByteArrayOutputStream();
+        for (int i = 0; i < 6; i++) {
+            int scaledWidth = Math.round(sourceImage.getWidth() * scaleFactor);
+            int scaledHeight = Math.round(sourceImage.getHeight() * scaleFactor);
+            BufferedImage scaledImage = new BufferedImage(scaledWidth, scaledHeight, BufferedImage.TYPE_INT_RGB);
+            Graphics2D g = scaledImage.createGraphics();
+            g.setColor(Color.WHITE);
+            g.fillRect(0, 0, scaledWidth, scaledHeight);
+            g.drawImage(sourceImage, 0, 0, scaledWidth, scaledHeight, null);
+            g.dispose();
+            ByteArrayOutputStream os = new ByteArrayOutputStream();
 			try {
 				ImageIO.write(scaledImage, pictureFormat, os);
 			} catch (IOException e) {
@@ -438,4 +433,38 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 		checkResult(result, JSONResultType.JSONObject);
 		updateDataObjectFromJSONResult(object, requestedFields, result);
 	}
+	
+    @Override
+    public void writeDeletedDataObject(DataObject object) throws USMException {
+        if (_journal.isDebugEnabled())
+            _journal.debug(object.getSession() + " Delete contact with id " + object.getID() + " in folder " + object.getParentFolderID());
+        checkTypeToWrite(object, _contentType.getID());
+        Map<String, String> parameters = new HashMap<String, String>();
+        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
+        JSONObject jObj = new JSONObject();
+        try {
+            jObj.put(UtilConstants.ID, object.getID());
+            jObj.put(UtilConstants.FOLDER, object.getParentFolderID());
+        } catch (JSONException ignored) {
+            // can not happen with our fixed keys
+        }
+        JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_DELETE, object.getSession(), parameters, jObj);
+        checkResult(result, JSONResultType.JSONObject);
+        try {
+            JSONObject data = result.getJSONObject().getJSONObject(UtilConstants.RESULT_DATA);
+            if (data.length() > 0)
+                throw new ConflictingChangeException(
+                    USMContentTypesContactsErrorCodes.DELETE_FAILED,
+                    "Delete of contact '" + object.getID() + "' failed",
+                    data);
+            readOptionalTimestamp(result.getJSONObject(), object);
+        } catch (JSONException e) {
+            _journal.error("OX server did not send data object: " + result.toString());
+            throw new OXCommunicationException(
+                USMContentTypesContactsErrorCodes.DELETE_DATA_NOT_PRESENT,
+                "OX server did not send data object",
+                e,
+                result.toString());
+        }
+    }
 }
