@@ -67,14 +67,13 @@ public class ImageDataType extends AbstractDataType<Image> implements DataType<I
 	}
 
 	public Image extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
-		// Special case, image consists of multiple columns: image1, image_last_modified, image1_url and image1_content_type
-		// "image1" is currently ignored since it contains no usable data
+		// Special case, image consists of multiple columns: image_last_modified, image1_url and image1_content_type
 		//		String imageData = array.getString(index); // "image1"
-		long timestamp = array.isNull(index + 1) ? 0L : array.getLong(index + 1); // "image_last_modified"
+		long timestamp = array.isNull(index) ? 0L : array.getLong(index); // "image_last_modified"
 		if (timestamp == 0L)
 			return null;
-		String url = array.isNull(index + 2) ? null : array.getString(index + 2); // "image1_url"
-		String contentType = array.isNull(index + 3) ? null : array.getString(index + 3); // "image1_content_type"
+		String url = array.isNull(index + 1) ? null : array.getString(index + 1); // "image1_url"
+		String contentType = array.isNull(index + 2) ? null : array.getString(index + 2); // "image1_content_type"
 		return new Image(timestamp, url, contentType);
 	}
 
