@@ -109,6 +109,9 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
         String errorOnDuplicateNamePersistentField = session.getPersistentField(UtilConstants.ERROR_ON_DUPLICATE_NAME_DB_FIELD);
         if (errorOnDuplicateNamePersistentField != null && errorOnDuplicateNamePersistentField.length() > 0)
             parameters.put(UtilConstants.ERROR_ON_DUPLICATE_NAME, errorOnDuplicateNamePersistentField);
+        if(folder.getSession().getObjectsLimit() > 0) {
+            addObjectsLimitParameters(folder.getSession().getObjectsLimit(), parameters);
+        }
         DataObject[] listOfResults = performActionAndCheckRights(UtilConstants.ACTION_LIST, folder, requestedFields, parameters);
         Folder[] result = tranformToFolders(listOfResults);
         for (Folder f : result) {
