@@ -93,7 +93,11 @@ import com.openexchange.usm.ox_json.OXJSONAccess;
  *
  */
 public abstract class AbstractTransferHandler implements ContentTypeTransferHandler {
-	private static final String ERROR_PARAMS = "error_params";
+	private static final String RIGHT_HAND_LIMIT = "right_hand_limit";
+
+    private static final String LEFT_HAND_LIMIT = "left_hand_limit";
+
+    private static final String ERROR_PARAMS = "error_params";
 
 	public static final boolean CHECK_ACCESS_RIGHTS_BEFORE_FOLDER_READ = true;
 
@@ -655,6 +659,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 		if (folderTree != null) {
 			parameters.put(UtilConstants.TREE, folderTree);
 		}
+		if(folder.getSession().getObjectsLimit() > 0) {
+            addObjectsLimitParameters(folder.getSession().getObjectsLimit(), parameters);
+        }
 		return performActionAndCheckRights(action, folder, requestedFields, parameters);
 	}
 
@@ -849,6 +856,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 		if (folderTree != null) {
 			parameters.put(UtilConstants.TREE, folderTree);
 		}
+        if (folder.getSession().getObjectsLimit() > 0) {
+            addObjectsLimitParameters(folder.getSession().getObjectsLimit(), parameters);
+        }
 		JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), action, folder.getSession(), parameters);
 		return getListOfUpdates(folder, requestedFields, result);
 	}
@@ -949,4 +959,13 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 	public byte[] getAttachmentData(DataObject object, int attachmentId) throws USMException {
 		return _pimAttachmentsTransferHandler.getAttachmentData(object, attachmentId);
 	}
+	
+    protected void addObjectsLimitParameters(int limit, Map<String, String> parameters) {
+        parameters.put(LEFT_HAND_LIMIT, "0");
+        parameters.put(RIGHT_HAND_LIMIT, String.valueOf(limit));
+        if (!parameters.containsKey(UtilConstants.SORT)) {
+            parameters.put(UtilConstants.SORT, "5"); // sort by last modified
+            parameters.put(UtilConstants.ORDER, "desc");
+        }
+    }
 }
