@@ -85,12 +85,12 @@ public class USMContentTypesUtilErrorCodes {
 	public static final int OX_RESULT_ERROR_NUMBER8 = 0x400017;
 	public static final int OX_RESULT_ERROR_NUMBER9 = 0x400018;
 	public static final int OX_RESULT_ERROR_NUMBER10 = 0x400019;
-	public static final int OX_RESULT_ERROR_NUMBER11 = 0x400020;
-	public static final int OX_RESULT_ERROR_NUMBER12 = 0x400021;
-	public static final int OX_RESULT_ERROR_NUMBER13 = 0x400022;
-	public static final int OX_RESULT_ERROR_NUMBER14 = 0x400023;
-	public static final int OX_RESULT_ERROR_NUMBER15 = 0x400024;
-	public static final int OX_RESULT_ERROR_NUMBER16 = 0x400025;
+	public static final int OX_RESULT_ERROR_NUMBER11 = 0x40001A;
+	public static final int OX_RESULT_ERROR_NUMBER12 = 0x40001B;
+	public static final int OX_RESULT_ERROR_NUMBER13 = 0x40001C;
+	public static final int OX_RESULT_ERROR_NUMBER14 = 0x40001D;
+	public static final int OX_RESULT_ERROR_NUMBER15 = 0x40001E;
+	public static final int OX_RESULT_ERROR_NUMBER16 = 0x40001F;
 
 	/**
 	 * Data array is not present where expected in a JSON Result received from the OX server. 
