@@ -50,21 +50,17 @@ package com.openexchange.usm.connector.commands;
 
 import static com.openexchange.usm.connector.commands.CommandConstants.*;
 import static com.openexchange.usm.json.response.ResponseObject.*;
-
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
 import java.util.List;
 import java.util.Map;
 import java.util.UUID;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
-
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
 import com.openexchange.usm.api.database.DatabaseAccessException;
 import com.openexchange.usm.api.exceptions.FolderNotFoundException;
@@ -106,27 +102,46 @@ public class MoveItemsHandler extends SyncCommandHandler {
 	}
 
 	@Override
-	public ResponseObject handleRequest() throws USMJSONAPIException {
-		String sourceFolderUUID = getStringParameter(SOURCEFOLDERID);
-		String destinationFolderUUID = getStringParameter(DESTINATIONFOLDERID);
-		Folder sourceFolder = getFolderByUUID(sourceFolderUUID);
-		Folder destinationFolder = getFolderByUUID(destinationFolderUUID);
-		long sourceFolderSyncID = getLong(_parameters, SOURCESYNCID);
-		long destinationSyncID = getLong(_parameters, DESTINATIONSYNCID);
-		if (sourceFolderUUID.equals(destinationFolderUUID))
-			throw new USMJSONAPIException(ConnectorBundleErrorCodes.MOVE_ITEMS_SAME_SOURCE_DEST,
-					ResponseStatusCode.WRONG_MISSING_PARAMETERS, generateErrorMessage(
-							"Source and Destination are the same.", sourceFolder, sourceFolderSyncID,
-							destinationFolder, destinationSyncID));
-		JSONArray objectsToMove = getJSONArray(_parameters, OBJECTIDS);
+    public ResponseObject handleRequest() throws USMJSONAPIException {
+        String sourceFolderUUID = getStringParameter(SOURCEFOLDERID);
+        String destinationFolderUUID = getStringParameter(DESTINATIONFOLDERID);
 
-		//move items
-		JSONObject response = moveItems(sourceFolder, sourceFolderSyncID, destinationFolder, destinationSyncID,
-				objectsToMove);
-		return new ResponseObject(ResponseStatusCode.SUCCESS, response);
-	}
+        String acquirer = "moveItems:" + sourceFolderUUID + " -> " + destinationFolderUUID;
+        String previousAcquirer = _session.tryLock(sourceFolderUUID, acquirer);
+        if (previousAcquirer != null)
+            return createCannotLockFolderResponse("moveItems", "source ", sourceFolderUUID, previousAcquirer);
+        try {
+            previousAcquirer = _session.tryLock(destinationFolderUUID, acquirer);
+            if (previousAcquirer != null)
+                return createCannotLockFolderResponse("moveItems", "destination ", destinationFolderUUID, previousAcquirer);
+            try {
+                Folder sourceFolder = getFolderByUUID(sourceFolderUUID);
+                Folder destinationFolder = getFolderByUUID(destinationFolderUUID);
+                long sourceFolderSyncID = getLong(_parameters, SOURCESYNCID);
+                long destinationSyncID = getLong(_parameters, DESTINATIONSYNCID);
+                if (sourceFolderUUID.equals(destinationFolderUUID))
+                    throw new USMJSONAPIException(
+                        ConnectorBundleErrorCodes.MOVE_ITEMS_SAME_SOURCE_DEST,
+                        ResponseStatusCode.WRONG_MISSING_PARAMETERS,
+                        generateErrorMessage(
+                            "Source and Destination are the same.",
+                            sourceFolder,
+                            sourceFolderSyncID,
+                            destinationFolder,
+                            destinationSyncID));
+                JSONArray objectsToMove = getJSONArray(_parameters, OBJECTIDS);
+                // move items
+                JSONObject response = moveItems(sourceFolder, sourceFolderSyncID, destinationFolder, destinationSyncID, objectsToMove);
+                return new ResponseObject(ResponseStatusCode.SUCCESS, response);
+            } finally {
+                _session.unlock(destinationFolderUUID);
+            }
+        } finally {
+            _session.unlock(sourceFolderUUID);
+        }
+    }
 
-	private boolean checkExisting(Folder folder) {
+    private boolean checkExisting(Folder folder) {
 		BitSet fields = new BitSet();
 		try {
 			folder.getContentType().getTransferHandler().readFolder(folder, fields);
