@@ -195,17 +195,23 @@ public class PingHandler extends NormalCommandHandler {
 		return stringArray;
 	}
 
-	private JSONArray toUUIDsJSONArray(String[] idsArray) throws DatabaseAccessException, USMSQLException,
-			JSONException {
-		JSONArray result = new JSONArray();
-		for (int i = 0; i < idsArray.length; i++) {
-			Folder cachedFolder = getSession().getCachedFolder(idsArray[i]);
-			if (cachedFolder != null && isOfDefaultContentType(cachedFolder.getElementsContentTypeID())
-					&& cachedFolder.getUUID() != null)
-				result.put(cachedFolder.getUUID().toString());
-		}
-		return result;
-	}
+    private JSONArray toUUIDsJSONArray(String[] idsArray) throws DatabaseAccessException, USMSQLException, JSONException {
+        JSONArray result = new JSONArray();
+        for (int i = 0; i < idsArray.length; i++) {
+            if (isSpecialFolderType(idsArray[i]))
+                result.put(idsArray[i]);
+            else {
+                Folder cachedFolder = getSession().getCachedFolder(idsArray[i]);
+                if (cachedFolder != null && isOfDefaultContentType(cachedFolder.getElementsContentTypeID()) && cachedFolder.getUUID() != null)
+                    result.put(cachedFolder.getUUID().toString());
+            }
+        }
+        return result;
+    }
+	
+    private boolean isSpecialFolderType(String id) {
+        return DefaultContentTypes.GROUPS_ID.equals(id) || DefaultContentTypes.RESOURCES_ID.equals(id);
+    }
 
 	private boolean isOfDefaultContentType(String contentTypeID) {
 		return DefaultContentTypes.FOLDER_ID.equals(contentTypeID)
