@@ -102,7 +102,7 @@ public class SyncInitHandler extends SyncCommandHandler {
             long syncId = finishProcessingAndSaveNewState(result, folder, result.getTimestamp());
             JSONObject response = createResponseFromSyncResults(result, syncId);
             logSyncData(" syncInit", folderUUID, 0L, syncId, result.getTimestamp());
-            return new ResponseObject(ResponseStatusCode.SUCCESS, response);
+            return new ResponseObject(getSuccessResponseCode(), response);
         } finally {
             _session.unlock(lockKey);
         }
@@ -122,7 +122,7 @@ public class SyncInitHandler extends SyncCommandHandler {
 					EMPTY_DATAOBJECT_ARRAY);
 			addModificationsForExceptions(SyncResult.EMPTY_DATA_OBJECT_ARRAY, SyncResult.EMPTY_DATA_OBJECT_ARRAY,
 					_clientChangesArray); //create appointment exceptions in delayed calls
-			return _session.syncWithServer(_folderToSync.getID(), _limit, createFilter(_folderToSync), true,
+			return _session.syncWithServer(_folderToSync.getID(), _limit, getFilter(_folderToSync), true,
 					conflictResolution, _clientChangesArray);
 		} catch (USMJSONAPIException e) {
 			throw e;
