@@ -129,7 +129,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
     public ResponseObject handleRequest() throws USMJSONAPIException {
         String folderUUID = getStringParameter(FOLDERID, null);
         String lockKey = (folderUUID == null) ? "<FolderHierarchy>" : folderUUID;
-        String acquirer = "syncInit:" + lockKey;
+        String acquirer = "syncUpdate:" + lockKey;
         String previousAcquirer = _session.tryLock(lockKey, acquirer);
         if (previousAcquirer != null)
             return createCannotLockFolderResponse("syncInit", "", lockKey, previousAcquirer);
@@ -159,7 +159,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             logSyncData(" syncUpdate", folderUUID, _syncID, syncId, _syncResult.getTimestamp());
             if (usedOldSyncKey || isUnnecessaryAccess(folderUUID, response))
                 _servlet.getAccessLimiter().badAccessEncountered(_session);
-            return new ResponseObject(ResponseStatusCode.SUCCESS, response);
+            return new ResponseObject(getSuccessResponseCode(), response);
         } finally {
             _session.unlock(lockKey);
         }
@@ -310,7 +310,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 				syncId = _syncIdForUpdate;
 				_syncIdForUpdate = 0L;
 			}
-			return _session.syncChangesWithServer(_folderToSync.getID(), syncId, _limit, createFilter(_folderToSync),
+			return _session.syncChangesWithServer(_folderToSync.getID(), syncId, _limit, getFilter(_folderToSync),
 					true, conflictResolution, _clientChangesArray);
 		} catch (USMJSONAPIException e) {
 			throw e;
