@@ -57,24 +57,35 @@ public class EmailSizeFilter implements DataObjectFilter {
 
 	private final long _originalSyncID;
 
-	private final int _maxSize;
+	private final int _oneSyncSizeLimit;
+
+	private final int _maxEmailSize;
 
 	private int _size;
+	
+	private boolean _hadTooBigEmails;
 
-	public EmailSizeFilter(long originalSyncID, int maxSize) {
+	public EmailSizeFilter(long originalSyncID, int onesyncSizeLimit, int maxEmailSize) {
 		_originalSyncID = originalSyncID;
-		_maxSize = maxSize;
+		_oneSyncSizeLimit = onesyncSizeLimit;
+		_maxEmailSize = maxEmailSize;
 	}
 
-	public void initialize() {
+	@Override
+    public void initialize() {
 		_size = 0;
+		_hadTooBigEmails = false;
 	}
 
-	public boolean accept(DataObject object) {
-		return true;
+	@Override
+    public boolean accept(DataObject object) {
+	    boolean isTooBig = getMailSize(object) > _maxEmailSize;
+	    _hadTooBigEmails |= isTooBig;
+	    return !isTooBig;
 	}
 
-	public boolean addOperationToResult(ChangeState action, DataObject object) {
+	@Override
+    public boolean addOperationToResult(ChangeState action, DataObject object) {
 		if (object == null)
 			return false;
 		if (!DefaultContentTypes.MAIL_ID.equals(object.getContentType().getID()))
@@ -83,7 +94,7 @@ public class EmailSizeFilter implements DataObjectFilter {
 			case CREATED:
 			case MODIFIED:
 				int mailSize = getMailSize(object);
-				if (_size > 0 && _size + mailSize >= _maxSize)
+				if (_size > 0 && _size + mailSize >= _oneSyncSizeLimit)
 					return false;
 				_size += mailSize;
 				return true;
@@ -92,12 +103,17 @@ public class EmailSizeFilter implements DataObjectFilter {
 		}
 	}
 
-	private int getMailSize(DataObject object) {
+    private int getMailSize(DataObject object) {
 		Object o = object.getFieldContent("size");
 		return (o instanceof Number) ? ((Number) o).intValue() : DEFAULT_MAIL_SIZE;
 	}
 
-	public long getOriginalSyncID() {
+	@Override
+    public long getOriginalSyncID() {
 		return _originalSyncID;
 	}
+	
+	public boolean hadTooBigEmails() {
+	    return _hadTooBigEmails;
+	}
 }
