@@ -115,7 +115,7 @@ public interface ConnectorBundleErrorCodes {
 	int COMMAND_SYNC_CAN_NOT_READ_ATTACHMENTS = 0x610127;
 	int COMMAND_SYNC_ERROR_ON_CREATE_DELETE_ATTACHMENTS = 0x610128;
 	int COMMAND_SYNC_CAN_NOT_SAVE_SYNC_STATE = 0x610129;
-	int COMMAND_SYNC_ERROR_ON_RETRIEVE_ATTACHMENTS_FORM_SERVER = 0x61012A;
+	int COMMAND_SYNC_ERROR_ON_RETRIEVE_ATTACHMENTS_FROM_SERVER = 0x61012A;
 	int COMMAND_SYNC_CAN_NOT_RETRIEVE_CACHED_ELEMENTS = 0x61012B;
 	int COMMAND_SYNC_CAN_NOT_ADD_MEETING_REQUEST_TO_MAIL = 0x61012C;
 	int COMMAND_SYNC_CAN_NOT_CONVERT_ICAL_TO_MEETING_REQUEST = 0x61012D;
