@@ -49,10 +49,12 @@
 
 package com.openexchange.usm.json;
 
+import static com.openexchange.usm.json.ServletConstants.*;
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
+import java.io.Writer;
 import java.util.Map;
 import javax.servlet.ServletException;
 import javax.servlet.ServletOutputStream;
@@ -83,6 +85,8 @@ import com.openexchange.usm.util.AccessLimiter;
 import com.openexchange.usm.util.Toolkit;
 
 public class USMJSONServlet extends HttpServlet {
+    
+    private static final boolean _USE_RESPONSE_STREAMING = false;
 
     private static final int ONE_SECOND = 1000;
 
@@ -132,6 +136,8 @@ public class USMJSONServlet extends HttpServlet {
     private transient int _timefilterLimitFuture;
 
     private transient int _inboxPollingInterval;
+    
+    private transient int _maxEmailSize;
 
     private transient AccessLimiter _accessLimiter;
 
@@ -197,6 +203,10 @@ public class USMJSONServlet extends HttpServlet {
                 ConfigurationProperties.JSON_SERVLET_INBOX_POLLING_INTERVAL_PROPERTY,
                 ConfigurationProperties.JSON_SERVLET_INBOX_POLLING_INTERVAL_DEFAULT,
                 false);
+            _maxEmailSize = _configurationManager.getProperty(
+                ConfigurationProperties.JSON_SERVLET_MAX_EMAIL_SIZE_PROPERTY,
+                ConfigurationProperties.JSON_SERVLET_MAX_EMAIL_SIZE_DEFAULT,
+                false);
             int testInterval = _configurationManager.getProperty(
                 ConfigurationProperties.JSON_SERVLET_ACCESS_CHECK_TEST_INTERVAL_PROPERTY,
                 ConfigurationProperties.JSON_SERVLET_ACCESS_CHECK_TEST_INTERVAL_DEFAULT,
@@ -332,14 +342,23 @@ public class USMJSONServlet extends HttpServlet {
                 }
                 break;
             }
-            byte[] data = result.toString().getBytes(ServletConstants.UTF_ENCODING_8);
             response.setContentType(ServletConstants.USM_JSON_CONTENT_TYPE);
-            response.setContentLength(data.length);
-            ServletOutputStream os = response.getOutputStream();
-            if (os != null) {
-                os.write(data, 0, data.length);
-                os.flush();
-                os.close();
+            if(_USE_RESPONSE_STREAMING) {
+                Writer w = response.getWriter();
+                if(w != null) {
+                    result.write(w);
+                    w.flush();
+                    w.close();
+                }
+            } else {
+                byte[] data = result.toString().getBytes(ServletConstants.UTF_ENCODING_8);
+                response.setContentLength(data.length);
+                ServletOutputStream os = response.getOutputStream();
+                if (os != null) {
+                    os.write(data, 0, data.length);
+                    os.flush();
+                    os.close();
+                }
             }
             if (_journal.isDebugEnabled()) {
                 _journal.debug(generateTimeLog(handler, command, System.currentTimeMillis() - startTime));
@@ -460,15 +479,7 @@ public class USMJSONServlet extends HttpServlet {
     }
 
     public Session getSession(String user, String password, String device, String clientIP, Map<String, String> xHeaders) throws USMException {
-        Session session = _sessionManager.getSession(
-            user,
-            password,
-            ServletConstants.PROTOCOL,
-            device,
-            _sessionInitializer,
-            clientIP,
-            xHeaders);
-        session.resetClientIp(clientIP);
+        Session session = _sessionManager.getSession(user, password, PROTOCOL, device, _sessionInitializer, clientIP, xHeaders);
         return session;
     }
 
@@ -542,4 +553,7 @@ public class USMJSONServlet extends HttpServlet {
         return _accessLimiter;
     }
 
+    public int getMaxEmailSize() {
+        return _maxEmailSize;
+    }
 }
