@@ -132,17 +132,20 @@ public class DataObjectStorage {
     }
 
     public long put(String objectID, long timestamp, DataObjectSet objectSet, long timestampToKeep, SessionImpl session) throws DatabaseAccessException, USMSQLException {
+        Log journal = getJournal();
         CachedData data = getInternalCacheData(objectID);
         // If SyncState hasn't changed from newest SyncState stored, simply return the timestamp of the newest stored SyncState
         if (!session.getSessionManager().isForceNewSyncKeyOnEmptySync() && !hasStateChanged(data, objectSet, session)) {
-            return data.touchNewestTimestamp();
+            long newTimestamp = data.touchNewestTimestamp();
+            if (journal.isDebugEnabled())
+                journal.debug(_session + " Storing in DB cache not necessary, no changes for " + objectID + ", timestamp " + timestamp + "->" + newTimestamp + ", keeping " + timestampToKeep);
+            return newTimestamp;
         }
 
         Serializable[][] objects = serializeObjects(objectSet);
         boolean shouldKeepTimestamp = timestampToKeep > 0L;
         long newTS = data.store(timestamp, objects, timestampToKeep);
         long oldTS = data.getTimestamp(shouldKeepTimestamp ? 1 : 0);
-        Log journal = getJournal();
 
         if (journal.isDebugEnabled()) {
             if (shouldKeepTimestamp)
