@@ -587,19 +587,18 @@ public class SessionImpl implements Session, Serializable {
         long result = internalStoreCachedDataObjects(FOLDER_HIERARCHY_ID, oldTimestamp, timestamp, objects);
         if (!updatesPending)
             _lastFolderSync = result;
-        List<String> folderIDs = new ArrayList<String>();
+
         List<String> shortIDs = new ArrayList<String>();
         for (DataObject o : objects) {
             String id = o.getID();
-            folderIDs.add(id);
             shortIDs.add(getShortFolderID(id));
         }
+ 
         shortIDs.add(FOLDER_HIERARCHY_ID);
         for (String specialFolder : _sessionManager.getSpecialFolders())
             shortIDs.add(getShortFolderID(specialFolder));
         _dataObjectCache.retain(shortIDs.toArray(new String[shortIDs.size()]));
-        if (_folderIdMapping != null)
-            _folderIdMapping.retain(folderIDs.toArray(new String[folderIDs.size()]));
+         //the short ids mapping should not be removed for non existing folders - because a deletion should be reported to the client first with the correct short id (see bug 26252)
         return result;
     }
 
@@ -1046,9 +1045,12 @@ public class SessionImpl implements Session, Serializable {
     private String[] getAllFolderIDs(Folder[] folders) {
         if (folders == null)
             return new String[0];
-        String[] folderIds = new String[folders.length];
+        String[] folderIds = new String[folders.length + SessionManagerImpl.SPECIAL_FOLDERS.size()];
         for (int i = 0; i < folders.length; i++)
             folderIds[i] = folders[i].getID();
+        int foldersLength = folders.length;
+        for (int i = 0; i < SessionManagerImpl.SPECIAL_FOLDERS.size(); i++)
+            folderIds[foldersLength + i] = SessionManagerImpl.SPECIAL_FOLDERS.get(i);
         return folderIds;
     }
 
@@ -1143,6 +1145,14 @@ public class SessionImpl implements Session, Serializable {
     public void setMailLimit(int limit) {
         _mailLimit = limit;
     }
+    
+    public void setObjectsLimit(int limit) {
+        _sessionManager.setMaxObjectsPerFolder(limit);
+    }
+
+    public int getObjectsLimit() {
+        return _sessionManager.getMaxObjectsPerFolder();
+    }
 
     public String getFolderID(String shortFolderID) throws USMSQLException {
         if (shortFolderID.length() > 0) {
@@ -1299,7 +1309,7 @@ public class SessionImpl implements Session, Serializable {
         _clientIP = ip;
     }
 
-    public void resetClientIp(String ip) {
+    public void updateClientIp(String ip) {
         if (_clientIP.equals(ip))
             return;
         _clientIP = ip;
