@@ -118,7 +118,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
     public static final String LAST_ACCESS_FIELD_NAME = "USM_ACCESS";
 
-    private final static List<String> SPECIAL_FOLDERS = new ArrayList<String>();
+    public final static List<String> SPECIAL_FOLDERS = new ArrayList<String>();
 
     private final static List<String> SPECIAL_FOLDERS_VIEW = Collections.unmodifiableList(SPECIAL_FOLDERS);
 
@@ -163,6 +163,8 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
     private int _waitForChangesEmailMinPullDelay = -1;
 
     private int _maxSyncStatesInDB = ConfigurationProperties.SYNC_MAX_STATES_IN_DB_DEFAULT;
+    
+    private int _maxObjectsPerFolder = ConfigurationProperties.OBJECTS_IN_FOLDER_SYNC_LIMIT_DEFAULT;
 
     private boolean _keepLastSentSyncStateInDB = ConfigurationProperties.SYNC_KEEP_LAST_SENT_STATE_IN_DB_DEFAULT;
 
@@ -344,6 +346,18 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                 "Invalid configuration for " + ConfigurationProperties.USM_CACHE_SYNC_STATE_TIMEOUT_PROPERTY,
                 e);
         }
+        
+        try {
+            _maxObjectsPerFolder = _configurationManager.getProperty(
+                ConfigurationProperties.OBJECTS_IN_FOLDER_SYNC_LIMIT_PROPERTY,
+                ConfigurationProperties.OBJECTS_IN_FOLDER_SYNC_LIMIT_DEFAULT,
+                false);
+        } catch (USMInvalidConfigurationException e) {
+            throw new USMStartupException(
+                USMSessionManagementErrorCodes.CONFIGURATION_ERROR_16,
+                "Configuration for max_objects_per_folder is invalid",
+                e);
+        }
 
         _sessionStorage = new SessionStorage(this);
         _dataCache = new OXDataCache(cacheTimeLimitSyncComplete, cacheTimeLimitSyncIncomplete);
@@ -425,6 +439,7 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                     _oxAjaxAccess.login(session);
                 }
                 try {
+                    session.updateClientIp(clientIP);
                     recheckUSMAccess(initializer, session);
                     return session;
                 } catch (USMAccessDeniedException e) {
@@ -885,6 +900,16 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
     public void setSyncStateCacheTimeout(int timeout) {
         _syncStateCacheTimeout = timeout;
     }
+    
+    
+    public int getMaxObjectsPerFolder() {
+        return _maxObjectsPerFolder;
+    }
+
+    
+    public void setMaxObjectsPerFolder(int maxObjectsPerFolder) {
+       _maxObjectsPerFolder = maxObjectsPerFolder;
+    }
 
     public void updateCacheRemovals(int removedSessions, int jvmRemovals, int removedSyncStates) {
         _usmCacheInformation.sessionsRemovedDueToInactivity(removedSessions);
