@@ -61,7 +61,6 @@ import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.api.session.SessionInitializer;
 import com.openexchange.usm.api.session.SessionManager;
-import com.openexchange.usm.cache.CacheManager;
 import com.openexchange.usm.configuration.ConfigurationManager;
 import com.openexchange.usm.journal.Journal;
 import com.openexchange.usm.mapping.ObjectIdMappingService;
@@ -104,9 +103,7 @@ public class SessionManagerService implements SessionManager {
 		
 		_delegate.activate(journal.getLog(SessionManager.class), ajaxAccess, contentTypeManager,
 				folderContentTypeProvider.getFolderContentType(), oxEventManager, configurationManager, dbAccess,
-				mappingService, uuidService);
-		
-		_delegate.setTimerService(timerService);
+				mappingService, uuidService, timerService);
 	}
 
 	/*
@@ -115,7 +112,6 @@ public class SessionManagerService implements SessionManager {
 	 */
 	public void deactivate(ComponentContext context) {
 		_delegate.deactivate();
-		_delegate.setTimerService(null);
 	}
 
 	public void setManagementService(ManagementService managementService) {
@@ -126,25 +122,6 @@ public class SessionManagerService implements SessionManager {
 		_delegate.setManagementService(null);
 	}
 
-	/**
-	 * @param timerService
-	 * @deprecated It is now enabled via the activate method
-	 */
-	@Deprecated
-	public void setTimerService(TimerService timerService) {
-		_delegate.setTimerService(timerService);
-	}
-
-	/**
-     * 
-     * @param timerService
-     * @deprecated It is now disabled via the deactivate method
-     */
-	@Deprecated
-	public void unsetTimerService(TimerService timerService) {
-		_delegate.setTimerService(null);
-	}
-
 	public boolean existsSessionInDB(String user, String protocol, String device) throws USMException {
 		return _delegate.existsSessionInDB(user, protocol, device);
 	}
