@@ -94,15 +94,17 @@ public class UUIDMappingImpl implements UUIDMappingService {
 	public void activate(Log journal, DatabaseAccess dbAccess, CacheManager cacheManager) {
 		_journal = journal;
 		_dbAccess = dbAccess;
-		Properties cacheConfigProperties = new Properties();
+		Properties oxIdToUUIDCacheConfigProperties = new Properties();
+		Properties uuidToOxIdCacheConfigProperties = new Properties();
 		try {
-			cacheConfigProperties.load(new ByteArrayInputStream(UUIDCacheConfiguration.cacheConfiguration));
+		    oxIdToUUIDCacheConfigProperties.load(new ByteArrayInputStream(UUIDCacheConfiguration.oxObjectToUIDCache));
+		    uuidToOxIdCacheConfigProperties.load(new ByteArrayInputStream(UUIDCacheConfiguration.uuidToOxObjectCache));
 		} catch (IOException e) {
 			_journal.info("Can not load default configuration for UUID Mapping cache", e);
-			cacheConfigProperties = null;
+			oxIdToUUIDCacheConfigProperties = null;
 		}
-		_cacheOXObjectIDtoUUID = createCache("USMOXObjectIDToUUIDCache", cacheManager, cacheConfigProperties);
-		_cacheUUIDtoOXObjectID = createCache("USMUUIDToOXObjectIDCache", cacheManager, cacheConfigProperties);
+		_cacheOXObjectIDtoUUID = createCache(UUIDCacheConfiguration.USMOX_OBJECT_ID_TO_UUID_CACHE, cacheManager, oxIdToUUIDCacheConfigProperties);
+		_cacheUUIDtoOXObjectID = createCache(UUIDCacheConfiguration.USMUUID_TO_OX_OBJECT_ID_CACHE, cacheManager, uuidToOxIdCacheConfigProperties);
 		_journal.info("USM UUID mapping service activated");
 	}
 
@@ -126,11 +128,11 @@ public class UUIDMappingImpl implements UUIDMappingService {
 		_contextUUIDs.clear();
 		_dbAccess = null;
 		if (_cacheUUIDtoOXObjectID != null) {
-			_cacheUUIDtoOXObjectID.dispose();
+			_cacheUUIDtoOXObjectID.dispose(); //freeCache
 			_cacheUUIDtoOXObjectID = null;
 		}
 		if (_cacheOXObjectIDtoUUID != null) {
-			_cacheOXObjectIDtoUUID.dispose();
+			_cacheOXObjectIDtoUUID.dispose(); //freeCache
 			_cacheOXObjectIDtoUUID = null;
 		}
 		_journal.info("USM UUID mapping service deactivated");
